summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--1systems/tv/cd.nix4
-rw-r--r--1systems/tv/mkdir.nix4
-rw-r--r--1systems/tv/nomic.nix4
-rw-r--r--1systems/tv/rmdir.nix4
-rw-r--r--1systems/tv/wu.nix4
-rw-r--r--2configs/tv/exim-retiolum.nix4
-rw-r--r--3modules/tv/retiolum.nix29
7 files changed, 12 insertions, 41 deletions
diff --git a/1systems/tv/cd.nix b/1systems/tv/cd.nix
index 463d643a..2f8cf819 100644
--- a/1systems/tv/cd.nix
+++ b/1systems/tv/cd.nix
@@ -86,8 +86,8 @@ in
};
}
{
- imports = [ ../../3modules/tv/retiolum.nix ];
- tv.retiolum = {
+ imports = [ ../../3modules/krebs/retiolum.nix ];
+ krebs.retiolum = {
enable = true;
hosts = ../../Zhosts;
connectTo = [
diff --git a/1systems/tv/mkdir.nix b/1systems/tv/mkdir.nix
index e0e057d6..05d76c4c 100644
--- a/1systems/tv/mkdir.nix
+++ b/1systems/tv/mkdir.nix
@@ -29,8 +29,8 @@ with lib;
};
}
{
- imports = [ ../../3modules/tv/retiolum.nix ];
- tv.retiolum = {
+ imports = [ ../../3modules/krebs/retiolum.nix ];
+ krebs.retiolum = {
enable = true;
hosts = ../../Zhosts;
connectTo = [
diff --git a/1systems/tv/nomic.nix b/1systems/tv/nomic.nix
index 8e6812e4..bae12d36 100644
--- a/1systems/tv/nomic.nix
+++ b/1systems/tv/nomic.nix
@@ -37,8 +37,8 @@ with lib;
};
}
{
- imports = [ ../../3modules/tv/retiolum.nix ];
- tv.retiolum = {
+ imports = [ ../../3modules/krebs/retiolum.nix ];
+ krebs.retiolum = {
enable = true;
hosts = ../../Zhosts;
connectTo = [
diff --git a/1systems/tv/rmdir.nix b/1systems/tv/rmdir.nix
index b77a1c39..2cf9668c 100644
--- a/1systems/tv/rmdir.nix
+++ b/1systems/tv/rmdir.nix
@@ -29,8 +29,8 @@ with lib;
};
}
{
- imports = [ ../../3modules/tv/retiolum.nix ];
- tv.retiolum = {
+ imports = [ ../../3modules/krebs/retiolum.nix ];
+ krebs.retiolum = {
enable = true;
hosts = ../../Zhosts;
connectTo = [
diff --git a/1systems/tv/wu.nix b/1systems/tv/wu.nix
index 1d7bbe55..c5678a19 100644
--- a/1systems/tv/wu.nix
+++ b/1systems/tv/wu.nix
@@ -145,8 +145,8 @@ in
};
}
{
- imports = [ ../../3modules/tv/retiolum.nix ];
- tv.retiolum = {
+ imports = [ ../../3modules/krebs/retiolum.nix ];
+ krebs.retiolum = {
enable = true;
hosts = ../../Zhosts;
connectTo = [
diff --git a/3modules/tv/retiolum.nix b/3modules/tv/retiolum.nix
deleted file mode 100644
index d0037744..00000000
--- a/3modules/tv/retiolum.nix
+++ /dev/null
@@ -1,29 +0,0 @@
-{ config, lib, ... }:
-
-with lib;
-let
- cfg = config.tv.retiolum;
-
- out = {
- imports = [ ../../3modules/krebs/retiolum.nix ];
- options.tv.retiolum = api;
- config = mkIf cfg.enable imp;
- };
-
- api = {
- enable = mkEnableOption "tv.retiolum";
-
- connectTo = mkOption {
- type = with types; listOf str;
- };
-
- hosts = mkOption {
- type = types.path;
- };
- };
-
- imp = {
- krebs.retiolum = cfg;
- };
-
-in out
diff --git a/2configs/tv/exim-retiolum.nix b/2configs/tv/exim-retiolum.nix
index efab5cf3..851a0c62 100644
--- a/2configs/tv/exim-retiolum.nix
+++ b/2configs/tv/exim-retiolum.nix
@@ -4,9 +4,9 @@
services.exim =
# This configuration makes only sense for retiolum-enabled hosts.
# TODO modular configuration
- assert config.tv.retiolum.enable;
+ assert config.krebs.retiolum.enable;
let
# TODO get the hostname from config.tv.retiolum.
retiolumHostname = "${config.networking.hostName}.retiolum";
in
{ enable = true;
@@ -4,9 +4,9 @@
let
- # TODO get the hostname from config.tv.retiolum.
+ # TODO get the hostname from config.krebs.retiolum.
retiolumHostname = "${config.networking.hostName}.retiolum";
in